@@ -214,7 +214,7 @@ int brl_open_device (char *DeviceName, int Port, BRAILLE_EVENT_PROC EventProc)
 		else
 		{
 			/* unknown device */
-			fprintf (stderr, "brl_open_device: unknown device\n");
+			fprintf (stderr, "\nbrl_open_device: unknown device");
 			rv = 0;
 			/* errno = */
 		}		
@@ -231,12 +231,13 @@ int brl_open_device (char *DeviceName, int Port, BRAILLE_EVENT_PROC EventProc)
 			/* assert (Text && Attrs && Dots); */
 
 			/* clear all cells			 */
-      CurrentDevice->send_dots(Dots, CurrentDevice->CellCount, 1);	/* blocking send ;-) */
+    			CurrentDevice->send_dots(Dots, CurrentDevice->CellCount, 1);	/* blocking send ;-) */
 		}
 		else
 		{
-			fprintf (stderr, "brl_open_device: open device failed\n");	/* !!! TBR !!! be more explicit here */
+			fprintf (stderr, "\nbrl_open_device: open device failed");	/* !!! TBR !!! be more explicit here */
 			brl_close_device();
+			return 0;
 		}
 	
 	}
