@@ -55,9 +55,7 @@ SpeakerSettings speakers[]=
 extern GConfClient *gnopernicus_client;
 
 GnopernicusSpeakerListType 	*gnopernicus_speakers = NULL;
-GnopernicusSpeakerListType 	*gnopernicus_speakers_backup = NULL;
-SpeakerParameterType  		*speakers_parameters  = NULL;
-SpeakerParameterType  		*speakers_parameters_backup  = NULL;
+SpeakerSettingsListType  	*speakers_settings  = NULL;
 DictionaryListType		*dictionary_list = NULL;
 /**
  *
@@ -492,15 +490,15 @@ spconf_gnopernicus_speakers_get (void)
 }
 
 GnopernicusSpeakerListType*
-spconf_gnopernicus_speakers_clone (GnopernicusSpeakerListType* list)
+spconf_gnopernicus_speakers_clone (GnopernicusSpeakerListType* gs_list)
 {
     GnopernicusSpeakerListType *elem;
     GnopernicusSpeakerListType *clone = NULL;
     
-    if (!list) 
+    if (!gs_list) 
 	return NULL;
     
-    for (elem = list; elem ; elem = elem->next)
+    for (elem = gs_list; elem ; elem = elem->next)
     {
 	if (elem->data)
 	    clone = g_slist_append (clone, g_strdup ((gchar*)elem->data));
@@ -509,48 +507,48 @@ spconf_gnopernicus_speakers_clone (GnopernicusSpeakerListType* list)
 }
 
 GnopernicusSpeakerListType*
-spconf_gnopernicus_speakers_free (GnopernicusSpeakerListType *list)
+spconf_gnopernicus_speakers_free (GnopernicusSpeakerListType *gs_list)
 {
-    if (list)
-	list = spconf_free_slist_with_char_data (list);
+    if (gs_list)
+	gs_list = spconf_free_slist_with_char_data (gs_list);
 	
-    return list;
+    return gs_list;
 }
 
 GnopernicusSpeakerListType*
-spconf_gnopernicus_speakers_add (   GnopernicusSpeakerListType *list,
-				    const gchar *gn_speaker)
+spconf_gnopernicus_speakers_add (GnopernicusSpeakerListType *gs_list,
+				 const gchar *gn_speaker)
 {   
     GnopernicusSpeakerListType *elem;
 
     sru_return_val_if_fail (gn_speaker, NULL);
     
-    elem = spconf_gnopernicus_speakers_find (list, gn_speaker);
+    elem = spconf_gnopernicus_speakers_find (gs_list, gn_speaker);
     
     if (elem)
-	return list;
+	return gs_list;
 
-    list = g_slist_append ( list, g_strdup (gn_speaker));
+    gs_list = g_slist_append (gs_list, g_strdup (gn_speaker));
 					    
-    return list;
+    return gs_list;
 }
 
 GnopernicusSpeakerListType*
-spconf_gnopernicus_speakers_remove (GnopernicusSpeakerListType *list,
+spconf_gnopernicus_speakers_remove (GnopernicusSpeakerListType *gs_list,
 				    const gchar *gn_speaker)
 {
     GSList *elem = NULL;
     
-    sru_return_val_if_fail (gn_speaker, list);
-    sru_return_val_if_fail (list, NULL);
+    sru_return_val_if_fail (gs_list, NULL);
+    sru_return_val_if_fail (gn_speaker, gs_list);
 
-    elem = list;
+    elem = gs_list;
     while (elem)
     {
 	if (elem->data && !strcmp (gn_speaker, (gchar*)elem->data))
 	{
-	    list = g_slist_remove_link (list, elem);
-	    spconf_gnopernicus_speakers_save (list);
+	    gs_list = g_slist_remove_link (gs_list, elem);
+	    spconf_gnopernicus_speakers_save (gs_list);
 	    g_free (elem->data);
 	    g_slist_free (elem);
 	    elem = NULL;
@@ -558,21 +556,21 @@ spconf_gnopernicus_speakers_remove (GnopernicusSpeakerListType *list,
 	}
 	elem = elem->next;
     }
-    return list;
+    return gs_list;
 }
 
 
 GnopernicusSpeakerListType*
-spconf_gnopernicus_speakers_find (GnopernicusSpeakerListType *list,
+spconf_gnopernicus_speakers_find (GnopernicusSpeakerListType *gs_list,
 				  const gchar *gn_speaker)
 {   
     GnopernicusSpeakerListType *elem;
 
     sru_return_val_if_fail (gn_speaker, NULL);    
-    if (!list)
+    if (!gs_list)
 	return NULL;
         
-    for (elem = list; elem ; elem = elem->next)
+    for (elem = gs_list; elem ; elem = elem->next)
     {
 	if (!strcmp(elem->data, gn_speaker))
 	    return elem;
@@ -583,36 +581,36 @@ spconf_gnopernicus_speakers_find (GnopernicusSpeakerListType *list,
 
 
 GnopernicusSpeakerListType*
-spconf_gnopernicus_speakers_load (GnopernicusSpeakerListType* gs)
+spconf_gnopernicus_speakers_load (GnopernicusSpeakerListType* gs_list)
 {
-    GnopernicusSpeakerListType *list = NULL;
+    GnopernicusSpeakerListType *tmp_list = NULL;
     GConfValueType type;
     
-    gs = spconf_gnopernicus_speakers_free (gs);
+    gs_list = spconf_gnopernicus_speakers_free (gs_list);
 	
-    list = gnopiconf_get_list_with_default (
+    tmp_list = gnopiconf_get_list_with_default (
 		CONFIG_PATH SPEECH_VOICE_PARAM_KEY_PATH SPEECH_GNOPERNICUS_SPEAKERS,
 		NULL, &type);
 		
-    if (!list)
+    if (!tmp_list)
     {
 	gint iter;
 	for (iter = 0 ; iter < G_N_ELEMENTS(speakers); iter++)
-	    gs = g_slist_append (gs, g_strdup (speakers[iter].gnopernicus_speaker));
+	    gs_list = g_slist_append (gs_list, g_strdup (speakers[iter].gnopernicus_speaker));
 
-	spconf_gnopernicus_speakers_save (gs);
+	spconf_gnopernicus_speakers_save (gs_list);
 	
-	speakers_parameters =
-	    spconf_speaker_parameters_load_default ();
+	speakers_settings =
+	    spconf_speaker_settings_list_load_default ();
     }
     else
     {
-	gs = list;
-	speakers_parameters =
-	    spconf_speaker_parameters_load_from_gconf (gs);
+	gs_list = tmp_list;
+	speakers_settings =
+	    spconf_speaker_settings_list_load_from_gconf (gs_list);
     }
     
-    return gs;
+    return gs_list;
 }
 /*
 void
@@ -628,10 +626,10 @@ spconf_gnopernicus_speakers_debug ( GnopernicusSpeakerListType *gs)
 }
 */
 void
-spconf_gnopernicus_speakers_save ( GnopernicusSpeakerListType *gs)
+spconf_gnopernicus_speakers_save ( GnopernicusSpeakerListType *gs_list)
 {    
-    if (gs)
-	gnopiconf_set_list (gs, GCONF_VALUE_STRING,
+    if (gs_list)
+	gnopiconf_set_list (gs_list, GCONF_VALUE_STRING,
 			    CONFIG_PATH SPEECH_VOICE_PARAM_KEY_PATH SPEECH_GNOPERNICUS_SPEAKERS);
 			    
 }
@@ -688,20 +686,20 @@ spconf_speaker_settings_load (const gchar *key)
 }
 
 void
-spconf_speaker_settings_save (SpeakerSettings *value)
+spconf_speaker_settings_save (SpeakerSettings *speaker_settings)
 {
     gchar *path;
     GSList *list = NULL;
     
     path = g_strdup_printf ("%s%s", CONFIG_PATH SPEECH_VOICE_PARAM_KEY_PATH,
-			    value->gnopernicus_speaker);
+			    speaker_settings->gnopernicus_speaker);
     				    
     sru_assert (path);    
-    list = spconf_create_speaker_item (value);
+    list = spconf_create_speaker_item (speaker_settings);
     gnopiconf_set_list (list, GCONF_VALUE_STRING, path);
     g_free (path);	
     list = spconf_free_speaker_item (list);
-    spconf_speeach_voice_changes (value->gnopernicus_speaker);
+    spconf_speeach_voice_changes (speaker_settings->gnopernicus_speaker);
 }
 
 SpeakerSettings*
@@ -718,15 +716,15 @@ spconf_speaker_settings_new (void)
 }
 
 SpeakerSettings*
-spconf_speaker_settings_table_free_items (SpeakerSettings *table)
+spconf_speaker_settings_free (SpeakerSettings *speaker_settings)
 {
-    if (!table) 
+    if (!speaker_settings) 
 	return NULL;
-    g_free (table->gnopernicus_speaker);
-    g_free (table->gs_speaker);
-    g_free (table);
-    table = NULL;
-    return table;
+    g_free (speaker_settings->gnopernicus_speaker);
+    g_free (speaker_settings->gs_speaker);
+    g_free (speaker_settings);
+    speaker_settings = NULL;
+    return speaker_settings;
 }
 
 SpeakerSettings*
@@ -735,7 +733,7 @@ spconf_speaker_settings_copy (SpeakerSettings *dest,
 {
     sru_return_val_if_fail (source, NULL);
 
-    dest = spconf_speaker_settings_table_free_items (dest);
+    dest = spconf_speaker_settings_free (dest);
     dest = spconf_speaker_settings_new ();
 	
     sru_return_val_if_fail (dest, NULL);
@@ -750,21 +748,21 @@ spconf_speaker_settings_copy (SpeakerSettings *dest,
 }
 
 
-SpeakerParameterType*
-spconf_speaker_parameters_get ()
+SpeakerSettingsListType*
+spconf_speaker_settings_list_get (void)
 {
-    return speakers_parameters;
+    return speakers_settings;
 }
 
-SpeakerParameterType*
-spconf_speaker_parameters_clone (SpeakerParameterType *sp)
+SpeakerSettingsListType*
+spconf_speaker_settings_list_clone (SpeakerSettingsListType *sp_list)
 {
-    SpeakerParameterType *elem;
-    SpeakerParameterType *clone = NULL;
+    SpeakerSettingsListType *elem;
+    SpeakerSettingsListType *clone = NULL;
     
-    sru_return_val_if_fail (sp, NULL);
+    sru_return_val_if_fail (sp_list, NULL);
     
-    for (elem = sp; elem; elem = elem->next)
+    for (elem = sp_list; elem; elem = elem->next)
     {
 	SpeakerSettings *item = (SpeakerSettings*)elem->data;
 	SpeakerSettings *new_item = NULL;
@@ -784,16 +782,16 @@ spconf_speaker_parameters_clone (SpeakerParameterType *sp)
     return clone;
 }
 
-SpeakerParameterType*
-spconf_speaker_parameters_find (SpeakerParameterType *sp,
+SpeakerSettingsListType*
+spconf_speaker_settings_list_find (SpeakerSettingsListType *sp_list,
 		    	        const gchar *gnopernicus_speaker)
 {
     GSList *elem = NULL;
     
-    sru_return_val_if_fail (sp, NULL);
+    sru_return_val_if_fail (sp_list, NULL);
     sru_return_val_if_fail (gnopernicus_speaker, NULL);
     
-    for (elem = sp; elem ; elem = elem->next)
+    for (elem = sp_list; elem ; elem = elem->next)
     {
 	SpeakerSettings *item = (SpeakerSettings*)elem->data;
 	if (item)
@@ -807,8 +805,8 @@ spconf_speaker_parameters_find (SpeakerParameterType *sp,
     return NULL;
 }
 
-SpeakerParameterType*
-spconf_speaker_parameters_add (SpeakerParameterType *list, 
+SpeakerSettingsListType*
+spconf_speaker_settings_list_add (SpeakerSettingsListType *sp_list, 
 			     const gchar 	  *gn_speaker,
 			     const gchar 	  *gs_speaker,
 			     gint  volume,
@@ -816,34 +814,35 @@ spconf_speaker_parameters_add (SpeakerParameterType *list,
 			     gint  pitch)
 {
     SpeakerSettings *speaker = NULL;
-    SpeakerParameterType *elem = NULL;
+    SpeakerSettingsListType *elem = NULL;
     
-    sru_return_val_if_fail (gs_speaker, NULL);
-    sru_return_val_if_fail (gn_speaker, NULL);
+    sru_return_val_if_fail (gs_speaker, sp_list);
+    sru_return_val_if_fail (gn_speaker, sp_list);
 
 	
-    elem = spconf_speaker_parameters_find (list, gn_speaker);
+    elem = spconf_speaker_settings_list_find (sp_list, gn_speaker);
     
     if (elem)
-	return elem;
+	return sp_list;
     					    
     speaker = spconf_speaker_settings_new ();
 	
-    if (speaker)
-    {
-	speaker->gnopernicus_speaker = g_strdup (gn_speaker);
-	speaker->gs_speaker = g_strdup (gs_speaker);
-	speaker->volume     = volume;
-	speaker->rate       = rate;
-	speaker->pitch      = pitch;
-	list = g_slist_append (list, speaker);
-    }
-    return list;
+    sru_return_val_if_fail (speaker, sp_list);
+
+    speaker->gnopernicus_speaker = g_strdup (gn_speaker);
+    speaker->gs_speaker = g_strdup (gs_speaker);
+    speaker->volume     = volume;
+    speaker->rate       = rate;
+    speaker->pitch      = pitch;
+    
+    sp_list = g_slist_append (sp_list, speaker);
+
+    return sp_list;
 }
 
-SpeakerParameterType*
-spconf_speaker_parameters_copy (SpeakerParameterType *dest, 
-				SpeakerParameterType *source)
+SpeakerSettingsListType*
+spconf_speaker_settings_list_copy (SpeakerSettingsListType *dest, 
+				   SpeakerSettingsListType *source)
 {
     SpeakerSettings *speaker_dest = NULL;
     SpeakerSettings *speaker_source = NULL;
@@ -851,11 +850,11 @@ spconf_speaker_parameters_copy (SpeakerParameterType *dest,
     sru_return_val_if_fail (dest, NULL);
     sru_return_val_if_fail (source, NULL);
 	
-    speaker_dest = (SpeakerSettings*) dest->data;
+    speaker_dest   = (SpeakerSettings*) dest->data;
     speaker_source = (SpeakerSettings*) source->data;
 
     speaker_dest =
-	spconf_speaker_settings_table_free_items (speaker_dest);
+	spconf_speaker_settings_free (speaker_dest);
     speaker_dest = 
 	spconf_speaker_settings_new ();
 	
@@ -873,16 +872,16 @@ spconf_speaker_parameters_copy (SpeakerParameterType *dest,
 
 
 
-SpeakerParameterType*
-spconf_speaker_parameters_remove (SpeakerParameterType *list,
+SpeakerSettingsListType*
+spconf_speaker_settings_list_remove (SpeakerSettingsListType *sp_list,
 				 const gchar *gn_speaker)
 {
-    SpeakerParameterType *elem = NULL;
+    SpeakerSettingsListType *elem = NULL;
     
-    sru_return_val_if_fail (list, list);
-    sru_return_val_if_fail (gn_speaker, list);
+    sru_return_val_if_fail (sp_list, 	sp_list);
+    sru_return_val_if_fail (gn_speaker, sp_list);
     
-    elem = list;
+    elem = sp_list;
     
     while (elem)
     {
@@ -892,7 +891,7 @@ spconf_speaker_parameters_remove (SpeakerParameterType *list,
 	    if (!strcmp (gn_speaker, item->gnopernicus_speaker))
 	    {
 		gchar *path = NULL;
-		list = g_slist_remove_link (list, elem);
+		sp_list = g_slist_remove_link (sp_list, elem);
 		if (strcmp (NONE_ELEMENT, item->gnopernicus_speaker))
 		{
 		    path = g_strdup_printf ("%s%s", CONFIG_PATH SPEECH_VOICE_PARAM_KEY_PATH,
@@ -903,7 +902,7 @@ spconf_speaker_parameters_remove (SpeakerParameterType *list,
 		}
 		
 		elem->data = 
-		    spconf_speaker_settings_table_free_items ((SpeakerSettings*)elem->data);
+		    spconf_speaker_settings_free ((SpeakerSettings*)elem->data);
 		g_slist_free (elem);
 		elem = NULL;
 		break;
@@ -911,38 +910,37 @@ spconf_speaker_parameters_remove (SpeakerParameterType *list,
 	}
 	elem = elem->next;
     }
-    return list;
+    return sp_list;
 }
 
 
-SpeakerParameterType*
-spconf_speaker_parameters_free (SpeakerParameterType *list)
+SpeakerSettingsListType*
+spconf_speaker_settings_list_free (SpeakerSettingsListType *sp_list)
 {
-    SpeakerParameterType *elem = list;
-    if (!list) 
+    SpeakerSettingsListType *elem = sp_list;
+    if (!sp_list) 
 	return NULL;
     
     while (elem)
     {
         elem->data = 
-		spconf_speaker_settings_table_free_items ((SpeakerSettings*)elem->data);
+		spconf_speaker_settings_free ((SpeakerSettings*)elem->data);
 	elem = elem->next;
     }
 	
-    g_slist_free (list);
-    list = NULL;
+    g_slist_free (sp_list);
+    sp_list = NULL;
     
-    return list;
+    return sp_list;
 }
 
-SpeakerParameterType *
-spconf_speaker_parameters_load_default ()
+SpeakerSettingsListType *
+spconf_speaker_settings_list_load_default (void)
 {
     gint iter;
     
-    if (speakers_parameters)
-	speakers_parameters =
-	    spconf_speaker_parameters_free  (speakers_parameters);
+    speakers_settings =
+	    spconf_speaker_settings_list_free  (speakers_settings);
 	
     for (iter = 0 ; iter < G_N_ELEMENTS (speakers); iter++)
     {
@@ -958,22 +956,21 @@ spconf_speaker_parameters_load_default ()
 	    
 	    spconf_speaker_settings_save (speaker);
 	    
-	    speakers_parameters = 
-		g_slist_append (speakers_parameters, speaker);
+	    speakers_settings = 
+		g_slist_append (speakers_settings, speaker);
 	}
     }
     
-    return speakers_parameters;
+    return speakers_settings;
 }
 
-SpeakerParameterType *
-spconf_speaker_parameters_load_from_gconf (GnopernicusSpeakerListType *gnopernicus_speakers)
+SpeakerSettingsListType *
+spconf_speaker_settings_list_load_from_gconf (GnopernicusSpeakerListType *gnopernicus_speakers)
 {
-    SpeakerParameterType *elem = NULL;
+    SpeakerSettingsListType *elem = NULL;
 
-    if (speakers_parameters)
-	speakers_parameters = 
-	    spconf_speaker_parameters_free  (speakers_parameters);
+    speakers_settings = 
+	    spconf_speaker_settings_list_free  (speakers_settings);
 
 	
     for (elem = gnopernicus_speakers; elem ; elem = elem->next)
@@ -982,24 +979,24 @@ spconf_speaker_parameters_load_from_gconf (GnopernicusSpeakerListType *gnopernic
 	    spconf_speaker_settings_load ((gchar*)elem->data);
 	if (speaker)
 	{
-	    speakers_parameters = 
-			g_slist_append (speakers_parameters, speaker);
+	    speakers_settings = 
+			g_slist_append (speakers_settings, speaker);
 	}
 	else
 	    continue;
     }
 
-    return speakers_parameters;
+    return speakers_settings;
 }
 
 void
-spconf_speaker_parameters_save (SpeakerParameterType *sp)
+spconf_speaker_settings_list_save (SpeakerSettingsListType *sp_list)
 {
-    SpeakerParameterType *elem = NULL;
+    SpeakerSettingsListType *elem = NULL;
         
-    sru_return_if_fail (sp);
+    sru_return_if_fail (sp_list);
     
-    for (elem = sp; elem ; elem = elem->next)
+    for (elem = sp_list; elem ; elem = elem->next)
     {
 	SpeakerSettings *item = (SpeakerSettings*)elem->data;
 	if (item)
@@ -1013,8 +1010,8 @@ spconf_speakers_list_free (void)
 {
     gnopernicus_speakers =
 	spconf_gnopernicus_speakers_free (gnopernicus_speakers);
-    speakers_parameters =
-	spconf_speaker_parameters_free  (speakers_parameters);
+    speakers_settings =
+	spconf_speaker_settings_list_free  (speakers_settings);
 }
 
 
@@ -1125,7 +1122,7 @@ spconf_set_default_voices (gboolean force)
 
 		spconf_speaker_settings_save (speaker);	    
 		
-		spconf_speaker_settings_table_free_items (speaker);
+		spconf_speaker_settings_free (speaker);
 	    }
 	}
 
@@ -1322,12 +1319,11 @@ spconf_changes_cb			(GConfClient	*client,
 					gpointer	user_data)
 {        
     GnopernicusSpeakerListType *gs_list = NULL;
-    SpeakerParameterType       *sp_list = NULL;
+    SpeakerSettingsListType    *sp_list = NULL;
     gchar *key = NULL;
     gchar *path = NULL;
-	
-    sru_return_if_fail (entry);
-    if (!entry->value)
+
+    if (! entry || !entry->value)
 	return;
 	
     key = (gchar*) gconf_entry_get_key (entry);
@@ -1350,16 +1346,20 @@ spconf_changes_cb			(GConfClient	*client,
 	    SpeakerSettings *speaker = NULL;
 	    
 	    sp_list =
-		spconf_speaker_parameters_find (speakers_parameters, path);
+		spconf_speaker_settings_list_find (speakers_settings, path);
+		
 	    if (!sp_list) 
 		return;
 		
 	    speaker = spconf_speaker_settings_load (path);
+	
 	    if (!speaker)
 		return;
 	    
-	    spconf_speaker_settings_table_free_items ((SpeakerSettings *)sp_list->data);
+	    spconf_speaker_settings_free ((SpeakerSettings *)sp_list->data);
+	    
 	    sp_list->data = speaker;
-	    spui_modify_column_value (path, sp_list->data);
+	    
+	    spui_modify_speaker_values ((SpeakerSettings *)sp_list->data);
     }
 }
