@@ -76,6 +76,10 @@
 
 /*____________________________< SRCORE_DEFAULTS>____________________________*/
 /*____________________________< SPEECH_DEFAULTS>____________________________*/
+#define SPEECH_RATE_STEP			5
+#define SPEECH_VOLUME_STEP			5
+#define SPEECH_PITCH_STEP			5
+
 #define MAX_SPEECH_RATE				100
 #define MIN_SPEECH_RATE				0
 #define MAX_SPEECH_PITCH 			100
