@@ -1545,13 +1545,32 @@ static gboolean src_crosswire	    	= FALSE;
     if (config->key && 
 	strcmp (config->key, MAGNIFIER_ACTIVE_SCHEMA MAGNIFIER_VISIBLE) == 0)
     {
-    }
+    }*/
     else
     if (config->key && 
 	strcmp (config->key, MAGNIFIER_ACTIVE_SCHEMA MAGNIFIER_PANNING) == 0)
     {
+    	if (src_use_magnifier && 
+	    config->newvalue &&
+	    config->type == CFGT_BOOL);
+	{
+	    panning = *((gboolean*)config->newvalue);
+		
+	    if (src_use_speech)
+	    {
+		gchar *tmp;
+		tmp = g_strdup ( panning ? 
+				_("panning on") : 
+				_("panning off"));
+		src_say_message (tmp);
+		g_free (tmp);
+	    }
+
+	    if (!panning) 
+		src_magnifier_stop_panning (0);
+	}
     }
-*/
+
 }
 
 static void
